local Locale = {
	["enGB"] = {"\nLooking For Raid (Progress):", "\nWorld Bosses (Progress):", "RaidHelper - Settings"},
	["ruRU"] = {"\nПоиск рейда (Прогресс):", "\nМировые боссы (Прогресс):", "RaidHelper - Настройки"}
}

local LoceLe = GetLocale()
if LoceLe ~= "ruRU" then
	LoceLe = "enGB"
end

local IInfo = {
	[527] = 3,
	[528] = 3, 
	[529] = 3, 
	[530] = 3, 
	[526] = 4,
	[610] = 3,
	[611] = 3, 
	[612] = 3,
	[613] = 3,
	[716] = 4,
	[717] = 4,
	[724] = 3,
	[725] = 3, 

	[726] = 4,
	[728] = 4,
	[729] = 3,
	[730] = 3,
}

function RaidFinderQueueFrameSelectionDropDown_Initialize(self)
	local info = UIDropDownMenu_CreateInfo()
	for i=1, GetNumRFDungeons() do
		local id, name = GetRFDungeonInfo(i)
		local isAvailable, isAvailableToPlayer = IsLFGDungeonJoinable(id)
		local _, BKill = GetLFGDungeonNumEncounters(id)
		if BKill == IInfo[id] then
			name = string.format("|cffff0000%s [%d/%d]|r", name , BKill, IInfo[id])
		else
			name = string.format("%s [%d/%d]", name , BKill, IInfo[id])
		end
		if ( isAvailable or isAvailableToPlayer or isRaidFinderDungeonDisplayable(id) ) then
			if ( isAvailable ) then
				-- Если рейд доступен
				info.text = name
				info.value = id
				info.isTitle = nil
				info.func = RaidFinderQueueFrameSelectionDropDownButton_OnClick
				info.disabled = nil
				info.checked = (RaidFinderQueueFrame.raid == info.value)
				info.tooltipWhileDisabled = nil
				info.tooltipOnButton = nil
				info.tooltipTitle = nil
				info.tooltipText = nil
				UIDropDownMenu_AddButton(info)
			else
				-- Если рейд не доступен
				info.text = name 
				info.value = id
				info.isTitle = nil
				info.func = nil
				info.disabled = 1
				info.checked = nil
				info.tooltipWhileDisabled = 1
				info.tooltipOnButton = 1
				info.tooltipTitle = YOU_MAY_NOT_QUEUE_FOR_THIS
				info.tooltipText = LFGConstructDeclinedMessage(id)
				UIDropDownMenu_AddButton(info)
			end
		end
	end
end

local MapIconPosition = 
	{
		["ROUND"] = {true, true, true, true},
		["SQUARE"] = {false, false, false, false},
		["CORNER-TOPLEFT"] = {true, false, false, false},
		["CORNER-TOPRIGHT"] = {false, false, true, false},
		["CORNER-BOTTOMLEFT"] = {false, true, false, false},
		["CORNER-BOTTOMRIGHT"] = {false, false, false, true},
		["SIDE-LEFT"] = {true, true, false, false},
		["SIDE-RIGHT"] = {false, false, true, true},
		["SIDE-TOP"] = {true, false, true, false},
		["SIDE-BOTTOM"] = {false, true, false, true},
		["TRICORNER-TOPLEFT"] = {true, true, true, false},
		["TRICORNER-TOPRIGHT"] = {true, false, true, true},
		["TRICORNER-BOTTOMLEFT"] = {true, true, false, true},
		["TRICORNER-BOTTOMRIGHT"] = {false, true, true, true},
	}

local MapIcon = CreateFrame("Button", "MapIcons", Minimap)
MapIcon:SetHighlightTexture("Interface\\Minimap\\UI-Minimap-ZoomButton-Highlight")
MapIcon:SetWidth(44)
MapIcon:SetHeight(44)
MapIcon:SetFrameStrata("LOW")
MapIcon:SetMovable(true)
MapIcon:RegisterForDrag("LeftButton")
MapIcon:RegisterForClicks("AnyUp")
MapIcon:SetPoint("CENTER", Minimap, "CENTER", -90, -27)
MapIcon.icon = MapIcon:CreateTexture(nil, "BACKGROUND")
MapIcon.icon:SetTexture("Interface\\PlayerFrame\\UI-PlayerFrame-Deathknight-Death")
MapIcon.icon:SetWidth(30)
MapIcon.icon:SetHeight(30)
MapIcon.icon:SetPoint("CENTER", 0, 0)

MapIcon:SetScript("OnMouseDown", function(self, button)
	self.icon:SetPoint("CENTER", 1, -1)
end)
MapIcon:SetScript("OnMouseUp", function(self, button)
	self.icon:SetPoint("CENTER", 0, 0)
end)
MapIcon:SetScript("OnEnter",
	function(self)
	GameTooltip:SetOwner(self, "ANCHOR_LEFT")
	GameTooltip:AddDoubleLine("RaidHelper", "1.1")
	GameTooltip:AddLine(Locale[LoceLe][1])
	for i=1, GetNumRFDungeons() do
		local id, name = GetRFDungeonInfo(i)
		local isAvailable, isAvailableToPlayer = IsLFGDungeonJoinable(id)
		if isAvailable then
			local _, BKill = GetLFGDungeonNumEncounters(id)
			if BKill == IInfo[id] then
				GameTooltip:AddDoubleLine(name, "["..BKill.."/"..IInfo[id].."]", RED_FONT_COLOR.r, RED_FONT_COLOR.g, RED_FONT_COLOR.b)
			else
				GameTooltip:AddDoubleLine(name, "["..BKill.."/"..IInfo[id].."]", 1, 1, 1)
			end
		end
	end
	GameTooltip:AddLine(Locale[LoceLe][2])
	for index = 1, GetNumSavedWorldBosses() do
		local WBname = GetSavedWorldBossInfo(index)
		if WBname then
			GameTooltip:AddDoubleLine(WBname, "[1/1]", RED_FONT_COLOR.r, RED_FONT_COLOR.g, RED_FONT_COLOR.b)
		end
	end
	GameTooltip:Show()
	end)
MapIcon:SetScript("OnLeave", function(self) 
	GameTooltip:Hide()
	self.icon:SetPoint("CENTER", 0, 0)
end)

function UpdateMapIconPosition(self)
	if self.isMoving then
		local mx, my = Minimap:GetCenter()
		local px, py = GetCursorPosition()
		local scale = Minimap:GetEffectiveScale()
		px, py = px / scale, py / scale
	
		local angle = math.rad(math.deg(math.atan2(py - my, px - mx)) % 360)
		
		local x, y, q = math.cos(angle), math.sin(angle), 1
		if x < 0 then q = q + 1 end
		if y > 0 then q = q + 2 end
		local minimapShape = GetMinimapShape and GetMinimapShape() or "ROUND"
		local quadTable = MapIconPosition[minimapShape]
		if quadTable[q] then
			x, y = x*95, y*95
		else
			local diagRadius = math.sqrt(2*(95)^2)-10
			x = math.max(-95, math.min(x*diagRadius, 95))
			y = math.max(-95, math.min(y*diagRadius, 95))
		end
		self:ClearAllPoints()
		self:SetPoint("CENTER", Minimap, "CENTER", x, y)
		--print(x)
		--print(y)
	end
end

MapIcon:SetScript("OnDragStart", function(self)
	if IsShiftKeyDown() then
		self.isMoving = true
		self:SetScript("OnUpdate", function(self) UpdateMapIconPosition(self) end)
	end
end)

MapIcon:SetScript("OnDragStop", function(self)
	self.isMoving = nil
	self:SetScript("OnUpdate", nil)
	self:SetUserPlaced(true)
end)



